Metadata
--------

Extraction
^^^^^^^^^^

.. automodule:: s1ard.metadata.extract
    :members:
    :undoc-members:
    :show-inheritance:

    .. autosummary::
        :nosignatures:

        calc_enl
        calc_geolocation_accuracy
        calc_performance_estimates
        calc_pslr_islr
        copy_src_meta
        find_in_annotation
        geometry_from_vec
        get_header_size
        get_osv_info
        get_prod_meta
        get_src_meta
        meta_dict

XML
^^^

.. automodule:: s1ard.metadata.xml
    :members:
    :undoc-members:
    :show-inheritance:

    .. autosummary::
        :nosignatures:

        parse
        product_xml
        source_xml

STAC
^^^^

.. automodule:: s1ard.metadata.stac
    :members:
    :undoc-members:
    :show-inheritance:

    .. autosummary::
        :nosignatures:

        parse
        product_json
        source_json
        make_catalog